==> pydantic_cli-2.2.0.tar.gz: pydantic_cli-2.2.0/pydantic_cli/examples/subparser.py <==
"""
Example of Using a Subparser
"""
import sys
import logging
import typing as T
from pydantic import BaseModel, AnyUrl

from pydantic_cli.examples import ExampleConfigDefaults, LogLevel
from pydantic_cli import run_sp_and_exit, SubParser, DefaultConfig

log = logging.getLogger(__name__)


class AlphaOptions(BaseModel):
    class Config(DefaultConfig, ExampleConfigDefaults):
        CLI_EXTRA_OPTIONS = {
            "max_records": ("-m", "--max-records"),
            "input_file": ("-i",),
        }
        CLI_JSON_ENABLE = True

    input_file: str
    max_records: int = 10
    log_level: LogLevel = LogLevel.DEBUG


class BetaOptions(BaseModel):
    class Config(ExampleConfigDefaults):
        CLI_EXTRA_OPTIONS = {
            "url": ("-u", "--url"),
            "num_retries": ("-n", "--num-retries"),
            "input_file": ("-i",),
        }
        CLI_JSON_ENABLE = True

    url: AnyUrl
    num_retries: int = 3
    log_level: LogLevel = LogLevel.INFO


def prologue_handler(opts):
    """Define a general Prologue hook to setup logging for the application"""
    format_str = (
        "[%(levelname)s] %(asctime)s [%(name)s %(funcName)s %(lineno)d] %(message)s"
    )
    logging.basicConfig(
        level=opts.log_level.upper(), stream=sys.stdout, format=format_str
    )
    log.info(f"Set up log with level {opts.log_level} with opts:{opts}")
    log.debug(f"Running {__file__}")


def printer_runner(opts: T.Any):
    print(f"Mock example running with {opts}")
    return 0


def to_runner(sx):
    def example_runner(opts) -> int:
        print(f"Mock {sx} example running with {opts}")
        return 0

    return example_runner


def to_subparser_example():

    return {
        "alpha": SubParser(AlphaOptions, to_runner("Alpha"), "Alpha SP Description"),
        "beta": SubParser(BetaOptions, to_runner("Beta"), "Beta SP Description"),
    }


if __name__ == "__main__":
    run_sp_and_exit(
        to_subparser_example(),
        description=__doc__,
        version="0.1.0",
        prologue_handler=prologue_handler,
    )

==> pydantic_cli-3.0.0.tar.gz: pydantic_cli-3.0.0/pydantic_cli/examples/subparser.py <==
"""
Example of Using a Subparser

Demonstration of using two Pydantic data models to
build a subparser.

For example,

my-tool alpha --help
my-tool beta --help
"""
import sys
import logging
import typing as T
from pydantic import BaseModel, AnyUrl

from pydantic_cli.examples import ExampleConfigDefaults, LogLevel, prologue_handler
from pydantic_cli import run_sp_and_exit, SubParser, DefaultConfig

log = logging.getLogger(__name__)


class AlphaOptions(BaseModel):
    class Config(DefaultConfig, ExampleConfigDefaults):
        CLI_EXTRA_OPTIONS = {
            "max_records": ("-m", "--max-records"),
            "input_file": ("-i",),
        }
        CLI_JSON_ENABLE = True

    input_file: str
    max_records: int = 10
    log_level: LogLevel = LogLevel.DEBUG


class BetaOptions(BaseModel):
    class Config(DefaultConfig, ExampleConfigDefaults):
        CLI_EXTRA_OPTIONS = {
            "url": ("-u", "--url"),
            "num_retries": ("-n", "--num-retries"),
            "input_file": ("-i",),
        }
        CLI_JSON_ENABLE = True

    url: AnyUrl
    num_retries: int = 3
    log_level: LogLevel = LogLevel.INFO


def to_func(sx):
    """ Util func to create to custom mocked funcs that be used be each subparser"""

    def example_runner(opts) -> int:
        print(f"Mock {sx} example running with {opts}")
        return 0

    return example_runner


def to_subparser_example() -> T.Dict[str, SubParser]:
    """Simply create a dict of SubParser and pass the dict
    to `run_sp_and_exit` or `to_runner_sp`
    """
    return {
        "alpha": SubParser[AlphaOptions](
            AlphaOptions, to_func("Alpha"), "Alpha SP Description"
        ),
        "beta": SubParser[BetaOptions](
            BetaOptions, to_func("Beta"), "Beta SP Description"
        ),
    }


if __name__ == "__main__":
    run_sp_and_exit(
        to_subparser_example(),
        description=__doc__,
        version="0.1.0",
        prologue_handler=prologue_handler,
    )
